ref_url: https://twitter.com/justmarkham/status/1192428355620130819 ref_name: Kevin Markham's Twitter ---

> 🐼🤹‍♂️ pandas trick #82:
> Want to select from a DataFrame by label *and* position?
> Most readable approach is to chain "loc" (selection by label) and "iloc" (selection by position).
> See example 👇
> Thanks to @Dean_La for this trick!#Python #DataScience #pandas #pandastricks pic.twitter.com/FCbkmaG6uD

> — Kevin Markham (@justmarkham) November 7, 2019